@@ -3,6 +3,7 @@ use crate::core::atom::{Atom, AtomKind};
 use crate::core::block::Block;
 use crate::core::constraint::PinConstraint;
 use crate::core::logic::Logic;
+use crate::core::prelude::TypeDescriptor;
 use crate::core::probe::Probe;
 use crate::core::signal::get_signal_id;
 use crate::core::synth::{Synth, VCDValue};
@@ -48,16 +49,8 @@ impl<T: Synth> Atom for Constant<T> {
         AtomKind::Constant
     }
 
-    fn is_enum(&self) -> bool {
-        T::ENUM_TYPE
-    }
-
-    fn name(&self, ndx: usize) -> &'static str {
-        T::name(ndx)
-    }
-
-    fn type_name(&self) -> &'static str {
-        T::TYPE_NAME
+    fn descriptor(&self) -> TypeDescriptor {
+        T::descriptor()
     }
 
     fn vcd(&self) -> VCDValue {
@@ -75,10 +68,6 @@ impl<T: Synth> Atom for Constant<T> {
     fn constraints(&self) -> Vec<PinConstraint> {
         vec![]
     }
-
-    fn signed(&self) -> bool {
-        T::SIGNED
-    }
 }
 
 impl<T: Synth> Block for Constant<T> {
