@@ -1,9 +1,8 @@
 use rand::Rng;
 use rust_hdl::core::prelude::*;
 use rust_hdl::hls::prelude::*;
-use rust_hdl::widgets::prelude::*;
 
-#[derive(LogicBlock, Default)]
+#[derive(LogicBlock)]
 struct MISOPortTest {
     bus: SoCBusController<16, 2>,
     bridge: Bridge<16, 2, 2>,
@@ -12,11 +11,23 @@ struct MISOPortTest {
     clock: Signal<In, Clock>,
 }
 
+impl Default for MISOPortTest {
+    fn default() -> Self {
+        Self {
+            bus: Default::default(),
+            bridge: Bridge::new(["port_a", "port_b"]),
+            port_a: Default::default(),
+            port_b: Default::default(),
+            clock: Default::default(),
+        }
+    }
+}
+
 impl Logic for MISOPortTest {
     #[hdl_gen]
     fn update(&mut self) {
         self.bus.clock.next = self.clock.val();
-        SoCBusController::<16,2>::join(&mut self.bus, &mut self.bridge.upstream);
+        SoCBusController::<16, 2>::join(&mut self.bus, &mut self.bridge.upstream);
         SoCPortController::<16>::join(&mut self.bridge.nodes[0], &mut self.port_a.bus);
         SoCPortController::<16>::join(&mut self.bridge.nodes[1], &mut self.port_b.bus);
     }
@@ -115,7 +126,7 @@ fn test_port_test_works() {
     .unwrap();
 }
 
-#[derive(LogicBlock, Default)]
+#[derive(LogicBlock)]
 struct MISOWidePortTest {
     bus: SoCBusController<16, 2>,
     bridge: Bridge<16, 2, 2>,
@@ -124,6 +135,18 @@ struct MISOWidePortTest {
     clock: Signal<In, Clock>,
 }
 
+impl Default for MISOWidePortTest {
+    fn default() -> Self {
+        Self {
+            bus: Default::default(),
+            bridge: Bridge::new(["port_a", "port_b"]),
+            port_a: Default::default(),
+            port_b: Default::default(),
+            clock: Default::default(),
+        }
+    }
+}
+
 impl Logic for MISOWidePortTest {
     #[hdl_gen]
     fn update(&mut self) {
@@ -243,7 +266,7 @@ fn test_wide_port_test_works() {
     ret.unwrap();
 }
 
-#[derive(LogicBlock, Default)]
+#[derive(LogicBlock)]
 struct MISOPortFIFOTest {
     bus: SoCBusController<16, 2>,
     bridge: Bridge<16, 2, 1>,
@@ -251,6 +274,17 @@ struct MISOPortFIFOTest {
     clock: Signal<In, Clock>,
 }
 
+impl Default for MISOPortFIFOTest {
+    fn default() -> Self {
+        Self {
+            bus: Default::default(),
+            bridge: Bridge::new(["port_a"]),
+            port_a: Default::default(),
+            clock: Default::default(),
+        }
+    }
+}
+
 impl Logic for MISOPortFIFOTest {
     #[hdl_gen]
     fn update(&mut self) {
